@@ -1,9 +1,13 @@
 var searchData=
 [
   ['libinput_5fconfig_5fstatus_5fto_5fstr',['libinput_config_status_to_str',['../group__config.html#ga7eee5ba99988d80bb9dd744894c72e06',1,'libinput.h']]],
+  ['libinput_5fdevice_5fconfig_5faccel_5fget_5fdefault_5fprofile',['libinput_device_config_accel_get_default_profile',['../group__config.html#ga288b904c2c0dcc188e3522291ab997c9',1,'libinput.h']]],
   ['libinput_5fdevice_5fconfig_5faccel_5fget_5fdefault_5fspeed',['libinput_device_config_accel_get_default_speed',['../group__config.html#ga71fba19df9d2cb15904c6351cec1af35',1,'libinput.h']]],
+  ['libinput_5fdevice_5fconfig_5faccel_5fget_5fprofile',['libinput_device_config_accel_get_profile',['../group__config.html#ga7f61a24d32878b0e8124695c10adef8f',1,'libinput.h']]],
+  ['libinput_5fdevice_5fconfig_5faccel_5fget_5fprofiles',['libinput_device_config_accel_get_profiles',['../group__config.html#gac2c57d3f082233b2cea696c8dbffee43',1,'libinput.h']]],
   ['libinput_5fdevice_5fconfig_5faccel_5fget_5fspeed',['libinput_device_config_accel_get_speed',['../group__config.html#gaac7c1b31e0131154d31b9167c876cc3b',1,'libinput.h']]],
   ['libinput_5fdevice_5fconfig_5faccel_5fis_5favailable',['libinput_device_config_accel_is_available',['../group__config.html#ga77b20c16fe26f385936f1d8cb4a1a560',1,'libinput.h']]],
+  ['libinput_5fdevice_5fconfig_5faccel_5fset_5fprofile',['libinput_device_config_accel_set_profile',['../group__config.html#ga6e72a6214840d76c8a43d3753c1d549d',1,'libinput.h']]],
   ['libinput_5fdevice_5fconfig_5faccel_5fset_5fspeed',['libinput_device_config_accel_set_speed',['../group__config.html#ga1d9761bb99b445524fb2ea801f946ef1',1,'libinput.h']]],
   ['libinput_5fdevice_5fconfig_5fcalibration_5fget_5fdefault_5fmatrix',['libinput_device_config_calibration_get_default_matrix',['../group__config.html#ga3d9f1b9be10e804e170c4ea455bd1f1b',1,'libinput.h']]],
   ['libinput_5fdevice_5fconfig_5fcalibration_5fget_5fmatrix',['libinput_device_config_calibration_get_matrix',['../group__config.html#gaa16e8b272ce94f8037822dc8c89d84a5',1,'libinput.h']]],
